package fireworx;

import java.sql.*;
import java.io.*;
import java.text.*;

public class QueryBean {
  
  private String houseCode;
  protected String dbURL;
  protected String dbDriver;
  protected String errorMessage;
  protected String sortBy;
  protected String sortOrder;
     
  protected Connection dbCon;
  protected int numColumns; 
  protected ResultSet rs = null; 
  protected ResultSetMetaData rsmd = null;

  public QueryBean() {
  }
  
  public boolean queryDatabase(String sql) {
  	
  	try {
      Class.forName(this.dbDriver);
      dbCon = DriverManager.getConnection(this.dbURL);
            
    } catch (ClassNotFoundException e) {
    	  this.errorMessage = "Database drivers not available";
    	  return false;
    } catch (SQLException e) {
    	  this.errorMessage = "Database URL is wrong";
    	  return false;
    }
    
    try {	
     	Statement s = dbCon.createStatement();
      rs = s.executeQuery(sql);
    } catch (SQLException e) {
    	 //dbCon.close();
       this.errorMessage = "Problem with database query. Check your SQL";
       return false;
   	}
   	
   	try {
     	rsmd = rs.getMetaData();
    	numColumns = rsmd.getColumnCount();
   	} catch (SQLException e) {
   		 //rs.close();
   		 //dbCon.close();
       this.errorMessage = "Problem with database result set.";
       return false;
   	}
    
    return true;
   }
   
  public void closeDatabase() {
    try {
  	  rs.close();
  	  dbCon.close();
  	  } catch (SQLException e) {
   	     this.errorMessage = "Problem with database result set.";
   	  }

  }

  public boolean updateDatabase(String sql) {
  	
  	try {
      Class.forName(this.dbDriver);
      dbCon = DriverManager.getConnection(this.dbURL);
            
    } catch (ClassNotFoundException e) {
    	  this.errorMessage = "Database drivers not available";
    	  return false;
    } catch (SQLException e) {
    	  this.errorMessage = "Database URL is wrong";
    	  return false;
    }
    
    try {	
     	Statement s = dbCon.createStatement();
      s.executeUpdate(sql);
    } catch (SQLException e) {
    	 //dbCon.close();
       this.errorMessage = "Problem with database query. Check your SQL";
       return false;
   	}
    
    return true;
   }
     
  //public ResultSet getResultSet() {
  //  return rs;	
  //}
      
  public int getColumnCount() {
  	return numColumns;
  }
  
  public String getColumnName(int count) {
  	try {
  	  return rsmd.getColumnName(count); 
  	} catch (SQLException e) {
  		return null;
  	}
  }
  
  public boolean getNextRow() {
  	try {
  	 	return rs.next();
  	} catch (SQLException e) {
  		this.errorMessage = "Problem getting database row.";
  		return false;
  	}

  }
    
  public String getColumnData(int column) {
  	try {
  	String dtype = rsmd.getColumnTypeName(column);
  	
  	SimpleDateFormat formatterOutDate = new SimpleDateFormat("MM/dd/yyyy");
  	SimpleDateFormat formatterOutTime = new SimpleDateFormat("hh: mm:ss a");
  	
  	if (dtype.equals("DATETIME")) {
  		if (rsmd.getColumnName(column).toUpperCase().indexOf("TIME") < 0)
  		  return formatterOutDate.format(rs.getDate(column));
  		else
  			return formatterOutTime.format(rs.getTime(column));
  	} 	
  	else {  	  	
  	  return rs.getString(column);
  	}
  	
   	} catch (SQLException e) {
  		return null;
  	}
  }

  
  public String getErrorMessage() {
    return this.errorMessage;
  }

 
  public void setHouseCode(String houseCode) {
    this.houseCode = houseCode;
  }

  public String getHouseCode() {
    return this.houseCode;
  }
  
  public void setDbURL(String dbURL) {
    this.dbURL = dbURL;
  }

  public String getDbURL() {
    return this.dbURL;
  }
  
  public void setDbDriver(String dbDriver) {
    this.dbDriver = dbDriver;
  }

  public String getDbDriver() {
    return this.dbDriver;
  }
  
  public void setSortBy(String sortBy) {
    this.sortBy = sortBy;
  }

  public String getSortBy() {
    return this.sortBy;
  }

  public void setSortOrder(String sortOrder) {
    this.sortOrder = sortOrder;
  }

  public String getSortOrder() {
    return this.sortOrder;
  }

 
}